@@ -85,6 +85,7 @@ class GreenSSLSocket(_original_sslsocket):
                         ssl_version=ssl_version,
                         ca_certs=ca_certs,
                         do_handshake_on_connect=False,
+                        ciphers=kw.get('ciphers'),
                     )
             ret.keyfile = keyfile
             ret.certfile = certfile
@@ -364,7 +365,7 @@ class GreenSSLSocket(_original_sslsocket):
                 sslobj = self._context._wrap_socket(self._sock, server_side, ssl_sock=self)
             else:
                 context = self.context if PY33 else self._context
-                sslobj = context._wrap_socket(self, server_side)
+                sslobj = context._wrap_socket(self, server_side, server_hostname=self.server_hostname)
         else:
             sslobj = sslwrap(self._sock, server_side, self.keyfile, self.certfile,
                              self.cert_reqs, self.ssl_version,
